==> cubicweb-trustedauth-0.2.1.tar.gz: cubicweb-trustedauth-0.2.1/test/unittest_trustedauth.py <==
# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of CubicWeb.
#
# CubicWeb is free software: you can redistribute it and/or modify it under the
# terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# CubicWeb is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.

"""unit tests for cubicweb.web.application"""

import base64, Cookie
import os
import sys
import logging
import tempfile

from logilab.common.testlib import TestCase, unittest_main
from logilab.common.decorators import clear_cache, classproperty

from cubicweb import AuthenticationError, Unauthorized
from cubicweb.devtools.testlib import CubicWebTC
from cubicweb.devtools.fake import FakeRequest
from cubicweb.web import LogOut, Redirect, INTERNAL_FIELD_VALUE
from cubicweb.web.views.basecontrollers import ViewController

CONFIG = u'''trustedauth-secret-key-file=%s'''
secretfile = None

def setUpModule():
    global secretfile
    config = TrustAuthTC.config
    home = config.apphome
    print home

class TrustAuthTC(CubicWebTC):

    ## def setup_database(self):
    ##     for log in 'cubicweb', 'cubicweb.cubes', 'cubicweb.twisted':
    ##         logger = logging.getLogger(log)
    ##         logger.handlers = [logging.StreamHandler(sys.stdout)]
    ##         logger.setLevel(logging.DEBUG)

    def test_login(self):
        req, origsession = self.init_authentication('http')
        req._headers['x-remote-user'] = 'admin'
        self.assertAuthSuccess(req, origsession)
        self.assertRaises(LogOut, self.app_publish, req, 'logout')
        self.assertEqual(len(self.open_sessions), 0)

    def test_failed_login(self):
        req, origsession = self.init_authentication('http')
        req._headers['x-remote-user'] = 'toto'
        self.assertAuthFailure(req)
        req._headers['x-remote-user'] = 'admin'
        self.assertAuthSuccess(req, origsession)
        self.assertRaises(LogOut, self.app_publish, req, 'logout')
        self.assertEqual(len(self.open_sessions), 0)

==> cubicweb-trustedauth-0.3.0.tar.gz: cubicweb-trustedauth-0.3.0/test/unittest_trustedauth.py <==
# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of CubicWeb.
#
# CubicWeb is free software: you can redistribute it and/or modify it under the
# terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# CubicWeb is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
"""unit tests for trustedauth cube"""

from cubicweb.devtools.testlib import CubicWebTC
from cubicweb.web import LogOut

from cubes.trustedauth.entities import set_secret

class TrustedAuthTC(CubicWebTC):

    @classmethod
    def init_config(cls, config):
        super(TrustedAuthTC, cls).init_config(config)
        # XXX secret file in data/allinone.conf is a relative path, so test may
        # fail depending on the CWD when starting them. Recall set_secret to fix
        # this
        set_secret(config, cls.datapath('secretfile'))

    def test_login(self):
        req, origsession = self.init_authentication('http')
        req.set_request_header('x-remote-user', 'admin', raw=True)
        self.assertAuthSuccess(req, origsession)
        self.assertRaises(LogOut, self.app_publish, req, 'logout')
        self.assertEqual(len(self.open_sessions), 0)

    def test_failed_login(self):
        req, origsession = self.init_authentication('http')
        req.set_request_header('x-remote-user', 'toto', raw=True)
        self.assertAuthFailure(req)
        req.set_request_header('x-remote-user', 'admin', raw=True)
        self.assertAuthSuccess(req, origsession)
        self.assertRaises(LogOut, self.app_publish, req, 'logout')
        self.assertEqual(len(self.open_sessions), 0)

if __name__ == "__main__":
    from logilab.common.testlib import unittest_main
    unittest_main()
